@@ -23,6 +23,25 @@ def format_query(query_ast, sql_dialect) -> str:
     return formatted_query
 
 
+def get_allowed_dialects(query_ast):
+    """
+
+    :param query_ast:
+    :return:
+    """
+    from .dialects import list_dialects
+
+    allowed_dialects = []
+    for dialect in list_dialects():
+        try:
+            format_query(query_ast=query_ast, sql_dialect=dialect)
+        except Exception:
+            pass
+        else:
+            allowed_dialects.append(dialect)
+    return allowed_dialects
+
+
 class BaseFormatter(MozFormatter):
     """"""
 
@@ -45,7 +64,21 @@ class BaseFormatter(MozFormatter):
         if isinstance(json, list):
             return "DISTINCT " + self.dispatch(json=json)
         else:
-            return "DISTINCT(" + self.dispatch(json=json) +')'
+            return "DISTINCT(" + self.dispatch(json=json) + ')'
+
+    def value(self, json):
+        parts = [self.dispatch(json["value"])]
+        if 'over' in json:
+            parts.extend(['OVER', self.over(json=json['over'])])
+        if "name" in json:
+            parts.extend(["AS", self.dispatch(json["name"])])
+        return " ".join(parts)
+
+    def over(self, json):
+        result = "(PARTITION BY " + self.dispatch(json=json['partitionby'])
+        if json.get('orderby'):
+            result += ' ' + self.orderby(json=json)
+        return result + ')'
 
     def format(self, json):
         if "union" in json:
