@@ -21,7 +21,7 @@ def parse_query(query, sql_dialect, feature_name=None) -> tuple:
     """
     dialect = load_dialect_module(dialect_name=sql_dialect)
     standardized_query = strip_comments(query=query)
-    standardized_query = pad_comparisons(query = standardized_query)
+    standardized_query = pad_comparisons(query=standardized_query)
     standardized_query, variables = wrap_variables(
         query=standardized_query, encoding_character='', wrap_character=ENCODING_CHARACTER,
     )
@@ -66,7 +66,7 @@ def label_input(variable_set, query_ast):
                     name=clean_name, display_name=display_name.split('.')[-1], default_value=default_value,
                     type=data_type, allows_list=allows_list, full_string=group,
                     locations=location,
-                    partial_string=partial_string
+                    is_partial_string=partial_string
                 )
     return list(variables.values())
 
